package cn.com.qmth.importpaper;

import java.io.File;
import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.apache.commons.io.IOUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;

import okhttp3.Response;

public class ImportPropByCourse {

	private static Logger logger = LogManager.getLogger(ImportPropByCourse.class);
	private final static String sourceDir = "d:/yunkai/";

	private static String batch = "230821";
	
	private static String host = "http://localhost:8008";
	private static String rootOrgId = "0";
	private static String key = "$SS:C_0_8";
	private static String token = "abf51dd054eb4192937d01904a1e966e";
	
//	private static String host = "http://192.168.1.249:8008";
//	private static String rootOrgId = "17351";
//	private static String key = "U_C_17351_646523";
//	private static String token = "6537edc191d546349fd5a4cb9e74b94b";
	

	public static void main(String[] args) {
		logger.debug("**********************导入开始");
		Date start = new Date();
		int errnum = 0;
		StringBuilder sb = new StringBuilder();

		int num = 0;
//		List<Course> cs = readSubject();
		Map<String,ImportCourse> ics=readSubjectCodes();
		for (ImportCourse ic : ics.values()) {
			File file = new File(sourceDir + "/prop/" + ic.getSubjectCode() + ".json");
			if(!file.exists()) {
				continue;
			}
			Date n = new Date();
			num++;
			try {
				if (file.exists()) {
					submit(ic, file);
					Date et = new Date();
					logger.debug("导入成功(" + num + ")：" + file.getName() + " 耗时：" + (et.getTime() - n.getTime()));
				}
			} catch (Exception e) {
				errnum++;
				sb.append(file.getName()).append(",");
				Date et = new Date();
				logger.error("导入失败(" + num + ")：" + file.getName() + " 耗时：" + (et.getTime() - n.getTime()) + " "
						+ e.getMessage(), e);
			}
		}

		Date end = new Date();
		logger.debug("**********************导入结束  耗时：" + (end.getTime() - start.getTime()));

		logger.debug("**********************导入出错数：" + errnum);
		logger.debug("**********************导入出错课程：" + sb.toString());
		OKHttpUtil.close();
	}

	private static Map<String,ImportCourse> readSubjectCodes() {
		Map<String,ImportCourse> map=new HashMap<>();
		XSSFWorkbook wb = null;
		try {
			wb = new XSSFWorkbook(sourceDir + "subject_info.xlsx");
			XSSFSheet sheet = wb.getSheetAt(0);
			int rows = sheet.getLastRowNum();
			for (int i = 1; i <= rows; i++) {
				Course c = new Course();
				XSSFRow row = sheet.getRow(i);
				String ecCode = row.getCell(0).getStringCellValue().trim();
				String yunCode = row.getCell(1).getStringCellValue().trim();
				String name = row.getCell(2).getStringCellValue().trim();
				c.setCode(ecCode);
				c.setName(name);
				ImportCourse ic=map.get(yunCode);
				if(ic==null) {
					ic=new ImportCourse();
					ic.setSubjectCode(yunCode);
					map.put(yunCode,ic);
				}
				ic.addCourse(c);
				
			}
		} catch (IOException e) {
			throw new RuntimeException(e);
		} finally {
			if (wb != null) {
				try {
					wb.close();
				} catch (IOException e) {
				}
			}
		}
		return map;
	}
	
//	private static List<Course> readSubject() {
//		List<Course> list = new ArrayList<>();
//		XSSFWorkbook wb = null;
//		try {
//			wb = new XSSFWorkbook(sourceDir + "subject.xlsx");
//			XSSFSheet sheet = wb.getSheetAt(0);
//			int rows = sheet.getLastRowNum();
//			for (int i = 1; i <= rows; i++) {
//				Course c = new Course();
//				XSSFRow row = sheet.getRow(i);
//				String id = row.getCell(0).getStringCellValue().trim();
//				String name = row.getCell(1).getStringCellValue().trim();
//				String code = row.getCell(2).getStringCellValue().trim();
//				c.setId(Long.valueOf(id));
//				c.setCode(code);
//				c.setName(name);
//				list.add(c);
//			}
//		} catch (IOException e) {
//			throw new RuntimeException(e);
//		} finally {
//			if (wb != null) {
//				try {
//					wb.close();
//				} catch (IOException e) {
//				}
//			}
//		}
//		return list;
//	}

	private static void submit(ImportCourse ic, File zfile) throws Exception {
		List<String> cs=ic.getCourses().stream().map(e->e.getCode()).collect(Collectors.toList());
		Map<String, String> params = Maps.newHashMap();
		params.put("rootOrgId", rootOrgId);
		params.put("batch", batch);
		params.put("courseCodes", StringUtils.join(cs,","));
		Map<String, String> headers = Maps.newHashMap();
		headers.put("key", key);
		headers.put("token", token);
		List<FormFilePart> fileList = Lists.newArrayList();
		fileList.add(new FormFilePart("dataFile", zfile.getName(), zfile));
		Response resp = null;
		try {
//			OKHttpUtil.initOkHttpClient();
			resp = OKHttpUtil.call(HttpMethod.POST, host + "/api/ecs_ques/importYunkaiProp", headers, params, fileList);
			if (resp.code() != 200) {
				throw new Exception(zfile.getName() + ":body:" + resp.body().string());
			}
		} finally {
			IOUtils.closeQuietly(resp);
		}
	}
}
